pub struct Image {
pub width: usize,
pub height: usize,
pub format: Format,
/* private fields */
}Expand description
A Netpbm image
Fields
width: usizeWidth of the image in pixels
height: usizeHeight of the image in pixels
format: FormatFormat of the image (pbm, pgm or ppm)
Implementations
Sourceimpl Image
impl Image
Sourcepub fn new(image_type: Format, width: usize, height: usize) -> Image
pub fn new(image_type: Format, width: usize, height: usize) -> Image
Create a new image of the given format and dimensions
pub fn width(&self) -> usize
pub fn height(&self) -> usize
Sourcepub fn set_pixel(&mut self, x: usize, y: usize, value: u8)
pub fn set_pixel(&mut self, x: usize, y: usize, value: u8)
Set the pixel at the given coordinates to a new color
pub fn get_pixel(&self, x: usize, y: usize) -> u8
Sourcepub fn write_to<W: Write>(
&self,
writer: &mut W,
encoding: Encoding,
) -> Result<()>
pub fn write_to<W: Write>( &self, writer: &mut W, encoding: Encoding, ) -> Result<()>
Write the image to a writer
pub fn read_from<R: Read>(reader: &mut R) -> Result<Self>